@@ -4,25 +4,31 @@
 * File: EditIP.Admin.class.php
 * This is the Edit IPBlacklist Module for the Geeklog Spam-X plugin
 *
-* Copyright (C) 2004-2008 by the following authors:
+* Copyright (C) 2004-2009 by the following authors:
 * Author   Tom Willett     tomw AT pigstye DOT net
 *          Dirk Haun       dirk AT haun-online DOT de
 *
 * Licensed under GNU General Public License
 *
-* $Id: EditIP.Admin.class.php,v 1.13 2008/09/21 08:37:08 dhaun Exp $
+* @package Spam-X
+* @subpackage Modules
 */
 
-if (strpos(strtolower($_SERVER['PHP_SELF']), 'EditIP.Admin.class.php') !== false) {
+if (strpos(strtolower($_SERVER['PHP_SELF']), 'editip.admin.class.php') !== false) {
     die('This file can not be used on its own!');
 }
 
 /**
-* IP Black List Editor
+* Include Abstract Base Class
 */
-
 require_once $_CONF['path'] . 'plugins/spamx/BaseAdmin.class.php';
 
+/**
+* IP Black List Editor
+*
+* @package Spam-X
+*
+*/
 class EditIP extends BaseAdmin {
     /**
      * Constructor
@@ -47,7 +53,8 @@ class EditIP extends BaseAdmin {
 
         if (($action == 'delete') && SEC_checkToken()) {
             $entry = addslashes($entry);
-            $result = DB_query("DELETE FROM {$_TABLES['spamx']} WHERE name = 'IP' AND value = '$entry'");
+            DB_delete($_TABLES['spamx'], array('name', 'value'),
+                                         array('IP', $entry));
         } elseif (($action == $LANG_SX00['addentry']) && SEC_checkToken()) {
             if (!empty($entry)) {
                 $entry = str_replace(' ', '', $entry);
