@@ -1,25 +1,37 @@
 <?php
 
-/**
- * File: italian.php
- * This is the Italian language page for the Geeklog Spam-X Plug-in!
- * 
- * Copyright (C) 2004 by the following authors:
- * Author        Tom Willett        tomw AT pigstye DOT net
- * Copyright (C) 2005 magomarcelo   magomarcelo AT gmail DOT com
- *                                  magomarcelo.blogspot.com
- *
- * Licensed under GNU General Public License
- *
- * $Id: italian.php,v 1.10 2008/05/02 15:08:10 dhaun Exp $
- */
+###############################################################################
+# italian.php
+#
+# This is the Italian language file for the Geeklog Spam-X Plugin
+#
+#  Copyright (C) 2004 Tom Willett         tomw AT pigstye DOT net
+#  Copyright (C) 2005 magomarcelo         magomarcelo AT gmail DOT com
+#                                         magomarcelo.blogspot.com
+#  Copyright (C) 2011 Rouslan Placella    rouslan {at} placella {dot} com
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#
+###############################################################################
 
 global $LANG32;
 
 $LANG_SX00 = array(
-    'inst1' => '<p>Cos&igrave; facendo, poi altri ',
-    'inst2' => 'saranno in grado di visualizzare ed importare la tua blacklist personale e noi possiamo creare un pi&ugrave; efficace ',
-    'inst3' => 'database distribuito.</p><p>Se hai iscritto il tuo sito web e decidi che non desideri pi&ugrave; che esso rimanga nella lista ',
+    'inst1' => '<p>Cos facendo, poi altri ',
+    'inst2' => 'saranno in grado di visualizzare ed importare la tua blacklist personale e noi possiamo creare un pi efficace ',
+    'inst3' => 'database distribuito.</p><p>Se hai iscritto il tuo sito web e decidi che non desideri pi che esso rimanga nella lista ',
     'inst4' => 'invia una e-mail a <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a> per dirmelo. ',
     'inst5' => 'Saranno onorate tutte le richieste.',
     'submit' => 'Invia',
@@ -28,11 +40,11 @@ $LANG_SX00 = array(
     'sitename' => 'Nome Sito: ',
     'URL' => 'URL Lista Spam-X: ',
     'RDF' => 'URL RDF: ',
-    'impinst1a' => 'Prima di utilizzare la funzionalit&agrave; di blocco commenti Spam di Spam-X per visualizzare ed importare le Blacklist personali da altri',
+    'impinst1a' => 'Prima di utilizzare la funzionalit di blocco commenti Spam di Spam-X per visualizzare ed importare le Blacklist personali da altri',
     'impinst1b' => ' siti, ti chiedo di premere sui due seguenti bottoni. (Devi premerne almeno uno.)',
     'impinst2' => 'Il primo registra il tuo sito web sul sito Gplugs/Spam-X in modo che possa essere aggiunto alla lista principale dei ',
-    'impinst2a' => 'siti che condividono le proprie blacklist. (Nota: se hai pi&ugrave; di un sito potresti volerne indicare uno solo come il ',
-    'impinst2b' => 'principale e registrare solo il suo nome. Ci&ograve; ti permetter&agrave; di aggiornare i tuoi siti facilmente e mantenere la lista pi&ugrave; piccola.) ',
+    'impinst2a' => 'siti che condividono le proprie blacklist. (Nota: se hai pi di un sito potresti volerne indicare uno solo come il ',
+    'impinst2b' => 'principale e registrare solo il suo nome. Ci ti permetter di aggiornare i tuoi siti facilmente e mantenere la lista pi piccola.) ',
     'impinst2c' => 'Dope aver premuto il bottone Invia, premi [back] sul tuo browser per tornare qui.',
     'impinst3' => 'Saranno inviati i seguenti valori: (puoi modificarli se sono errati).',
     'availb' => 'Blacklist Disponibili',
@@ -71,20 +83,20 @@ $LANG_SX00 = array(
     'viewlog' => 'Visualizza Log Spam-X',
     'clearlog' => 'Cancella File di Log',
     'logcleared' => '- File di Log di Spam-X Cancellato',
-    'plugin' => 'Plugin',
+    'plugin' => 'Estensione',
     'access_denied' => 'Accesso Negato',
     'access_denied_msg' => 'Solo gli Utenti Root possono Accedere a questa Pagina. Il Tuo nome utente ed IP sono stati registrati.',
-    'admin' => 'Amministrazione Plugin',
-    'install_header' => 'Installa/Disinstalla Plugin',
-    'installed' => 'Il Plugin &egrave; Installato',
-    'uninstalled' => 'Il Plugin Non &egrave; Installato',
-    'install_success' => 'Installation Successful',
-    'install_failed' => 'Installazione Fallita -- Controlla l\'error log per scoprire il perch&egrave;.',
-    'uninstall_msg' => 'Plugin Disinstallato con Successo',
+    'admin' => 'Amministrazione dell\'Estensione',
+    'install_header' => 'Installa/Disinstalla Estensione',
+    'installed' => 'L\'Estensione  Installata',
+    'uninstalled' => 'L\'Estensione non  Installata',
+    'install_success' => 'Installazione Completata con Successo',
+    'install_failed' => 'Installazione Fallita -- Controlla l\'error log per scoprire il perch.',
+    'uninstall_msg' => 'Estensione Disinstallata con Successo',
     'install' => 'Installa',
     'uninstall' => 'Disinstalla',
-    'warning' => 'Attenzione! Il plugin &egrave; ancora Attivo',
-    'enabled' => 'Disattiva il plugin prima di disinstallarlo.',
+    'warning' => 'Attenzione! L\'estensione  ancora Attiva',
+    'enabled' => 'Disattiva l\'estensione prima di disinstallarla.',
     'readme' => 'STOP! Prima di premere prego leggi il ',
     'installdoc' => 'Installa Documento.',
     'spamdeleted' => 'Commento Spam Eliminato',
@@ -97,8 +109,8 @@ $LANG_SX00 = array(
     'note2' => ' commenti spam e Spam-X non riesce a bloccarli. <ul><li>Prima cerca il o i link o altri ',
     'note3' => 'identificatori di questo commento Spam ed aggiungilo alla tua blacklist personale.</li><li>Poi ',
     'note4' => 'torna qui a fai controllare a Spam-X se gli ultimi commenti sono spam.</li></ul><p>I commenti ',
-    'note5' => 'vengono controllati dal pi&ugrave; recente al meno recente -- controllare pi&ugrave; commenti ',
-    'note6' => 'richiede pi&ugrave; tempo per il controllo</p>',
+    'note5' => 'vengono controllati dal pi recente al meno recente -- controllare pi commenti ',
+    'note6' => 'richiede pi tempo per il controllo</p>',
     'masshead' => '<hr' . XHTML . '><h1 align="center">Eliminazione in Blocco Commenti Spam</h1>',
     'masstb' => '<hr' . XHTML . '><h1 align="center">Mass Delete Trackback Spam</h1>',
     'comdel' => ' commenti eliminati.',
@@ -106,61 +118,64 @@ $LANG_SX00 = array(
     'initial_import' => 'Importazione Iniziale MT-Blacklist',
     'import_success' => '<p>Importati con successo %d elementi della blacklist.',
     'import_failure' => '<p><strong>Errore:</strong> Nessun elemento trovato.',
-    'allow_url_fopen' => '<p>Spiacente, la configurazione del tuo webserver non permette la lettura di file remoti (<code>allow_url_fopen</code> &egrave; off). Please download the blacklist from the following URL and upload it into Geeklog\'s "data" directory, <tt>%s</tt>, before trying again:',
-    'documentation' => 'Documentazione Plugin Spam-X',
-    'emailmsg' => "Un nuovo commento spam &egrave; stato inviato su \"%s\"\nUID utente:\"%s\"\n\nContenuto:\"%s\"",
-    'emailsubject' => 'Spam post at %s',
-    'ipblack' => 'Spam-X IP Blacklist',
-    'ipofurlblack' => 'Spam-X IP of URL Blacklist',
-    'headerblack' => 'Spam-X HTTP Header Blacklist',
-    'headers' => 'Request headers:',
-    'stats_headline' => 'Spam-X Statistics',
+    'allow_url_fopen' => '<p>Spiacente, la configurazione del tuo webserver non permette la lettura di file remoti (<code>allow_url_fopen</code>  off). Please download the blacklist from the following URL and upload it into Geeklog\'s \'data\' directory, <tt>%s</tt>, before trying again:',
+    'documentation' => 'Documentazione di Spam-X',
+    'emailmsg' => "Un nuovo commento spam  stato inviato su \"%s\"\nUID utente:\"%s\"\n\nContenuto:\"%s\"",
+    'emailsubject' => 'Commento Spam, %s',
+    'ipblack' => 'Blacklist degli IP di Spam-X',
+    'ipofurlblack' => 'Blacklist degli IP di indirizzi',
+    'headerblack' => 'Blacklist degli header HTTP',
+    'headers' => 'Headers delle Richieste:',
+    'stats_headline' => 'Statistiche di Spam-X',
     'stats_page_title' => 'Blacklist',
-    'stats_entries' => 'Entries',
+    'stats_entries' => 'Totale',
     'stats_mtblacklist' => 'MT-Blacklist',
-    'stats_pblacklist' => 'Personal Blacklist',
-    'stats_ip' => 'Blocked IPs',
-    'stats_ipofurl' => 'Blocked by IP of URL',
-    'stats_header' => 'HTTP headers',
-    'stats_deleted' => 'Posts deleted as spam',
+    'stats_pblacklist' => 'Blacklist Personale',
+    'stats_ip' => 'IP Bloccati',
+    'stats_ipofurl' => 'Bloccati con IP di indirizzi',
+    'stats_header' => 'Header HTTP',
+    'stats_deleted' => 'Inserimenti Rimossi (Spam)',
     'plugin_name' => 'Spam-X',
     'slvwhitelist' => 'SLV Whitelist'
 );
 
 // Define Messages that are shown when Spam-X module action is taken
-$PLG_spamx_MESSAGE128 = 'Spam identificato ed il Commento o Messaggio &egrave; stato eliminato.';
+$PLG_spamx_MESSAGE128 = 'Spam identificato ed il Commento o Messaggio  stato eliminato.';
 $PLG_spamx_MESSAGE8 = 'Spam identificato. E-mail inviata all\'amministratore.';
 
 // Messages for the plugin upgrade
-$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
+$PLG_spamx_MESSAGE3001 = 'L\'aggiornamento di Estensioni non supportato.';
 $PLG_spamx_MESSAGE3002 = $LANG32[9];
 
 // Localization of the Admin Configuration UI
 $LANG_configsections['spamx'] = array(
     'label' => 'Spam-X',
-    'title' => 'Spam-X Configuration'
+    'title' => 'Configurazione di Spam-X'
 );
 
 $LANG_confignames['spamx'] = array(
-    'action' => 'Spam-X Actions',
-    'notification_email' => 'Notification Email',
-    'admin_override' => 'Don\'t Filter Admin Posts',
-    'logging' => 'Enable Logging',
+    'spamx_action' => 'Spam-X Actions',
+    'notification_email' => 'Notifica via Email',
+    'logging' => 'Registrazione dell\'utilizzo e degli errori abilitata',
     'timeout' => 'Timeout'
 );
 
 $LANG_configsubgroups['spamx'] = array(
-    'sg_main' => 'Main Settings'
+    'sg_main' => 'Impostazioni Principali'
+);
+
+$LANG_tab['spamx'] = array(
+    'tab_main' => 'Spam-X Main Settings'
 );
 
 $LANG_fs['spamx'] = array(
-    'fs_main' => 'Spam-X Main Settings'
+    'fs_main' => 'Impostazioni Principali di Spam-X'
 );
 
 // Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
 $LANG_configselects['spamx'] = array(
-    0 => array('True' => 1, 'False' => 0),
-    1 => array('True' => true, 'False' => false)
+    0 => array('Vero' => 1, 'Falso' => 0),
+    1 => array('Vero' => true, 'Falso' => false)
 );
 
 ?>
