@@ -67,8 +67,8 @@ if (!SEC_hasRights('staticpages.edit')) {
 function staticpageeditor_form($A, $error = false)
 {
     global $_CONF, $_TABLES, $_USER, $_GROUPS, $_SP_CONF, $mode, $sp_id,
-           $LANG21, $LANG_STATIC, $LANG_ACCESS, $LANG_ADMIN, $LANG24,
-           $LANG_postmodes, $MESSAGE, $_IMAGE_TYPE;
+           $LANG21, $LANG_STATIC, $LANG_ACCESS, $LANG_ADMIN, $LANG01, $LANG24,
+           $LANG_postmodes, $MESSAGE, $_IMAGE_TYPE, $_SCRIPTS;
 
     $template_path = staticpages_templatePath('admin');
     if (!empty($sp_id) && $mode=='edit') {
@@ -91,9 +91,24 @@ function staticpageeditor_form($A, $error = false)
     }
     $retval = '';
 
-    $sp_template = new Template($template_path);
+    $sp_template = COM_newTemplate($template_path);
     if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
         $sp_template->set_file('form', 'editor_advanced.thtml');
+        
+        // Shouldn't really have to check if anonymous user but who knows...
+        if (COM_isAnonUser()) {
+            $link_message = "";
+        } else {
+            $link_message = $LANG01[138];    
+        } 
+        $sp_template->set_var('noscript', COM_getNoScript(false, '', $link_message));        
+        
+        // Add JavaScript
+        $js = 'geeklogEditorBasePath = "' . $_CONF['site_url'] . '/fckeditor/";';
+        // Hide the Advanced Editor as Javascript is required. If JS is enabled then the JS below will un-hide it
+        $js .= 'document.getElementById("advanced_editor").style.display="";';                 
+        $_SCRIPTS->setJavaScript($js, true);
+        $_SCRIPTS->setJavaScriptFile('staticpages_fckeditor', '/javascript/staticpages_fckeditor.js');
 
         $sp_template->set_var('lang_expandhelp', $LANG24[67]);
         $sp_template->set_var('lang_reducehelp', $LANG24[68]);
@@ -128,11 +143,6 @@ function staticpageeditor_form($A, $error = false)
         $sp_template->set_file('form', 'editor.thtml');
     }
 
-    $sp_template->set_var('xhtml', XHTML);
-    $sp_template->set_var('site_url', $_CONF['site_url']);
-    $sp_template->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $sp_template->set_var('layout_url', $_CONF['layout_url']);
-
     $sp_template->set_var('lang_mode', $LANG24[3]);
     $sp_template->set_var('comment_options',
                           COM_optionList($_TABLES['commentcodes'], 'code,name',
@@ -371,6 +381,25 @@ function staticpageeditor_form($A, $error = false)
     } else {
         $sp_template->set_var('hide_meta', ' style="display:none;"');
     }
+    if ($A['template_flag'] == 1) {
+        $sp_template->set_var('template_flag_checked', 'checked="checked"');
+    } else {
+        $sp_template->set_var('template_flag_checked', '');
+    }
+    $sp_template->set_var('lang_template', $LANG_STATIC['template']);
+    $sp_template->set_var('lang_template_flag_msg', $LANG_STATIC['template_msg']);    
+    
+    $template_list = templatelist($A['template_id']);
+    $template_none = '<option value=""';
+    if ($A['template_id'] == "") {
+        $template_none .= ' selected="selected"';
+    }
+    $template_none .= '>' . $LANG_STATIC['none'] . '</option>';
+    $sp_template->set_var('use_template_selection', '<select name="template_id">'
+                          . $template_none . $template_list . '</select>');
+    $sp_template->set_var('lang_use_template', $LANG_STATIC['use_template']);
+    $sp_template->set_var('lang_use_template_msg', $LANG_STATIC['use_template_msg']);
+    
     $sp_template->set_var('lang_addtomenu', $LANG_STATIC['addtomenu']);
     if (isset($A['sp_onmenu']) && ($A['sp_onmenu'] == 1)) {
         $sp_template->set_var('onmenu_checked', 'checked="checked"');
@@ -421,21 +450,10 @@ function staticpageeditor_form($A, $error = false)
                                $content);
     }
     $sp_template->set_var('sp_content', $content);
-    if ($_SP_CONF['filter_html'] == 1) {
-        $allowed = COM_allowedHTML('staticpages.edit');
-        $sp_template->set_var('lang_allowedhtml', $allowed);
-        $sp_template->set_var('lang_allowed_html', $allowed);
-    } else {
-        $sp_template->set_var('lang_allowedhtml',
-                              $LANG_STATIC['all_html_allowed']);
-        $allowed = '<span class="warningsmall">'
-                 . $LANG_STATIC['all_html_allowed'] . ',</span>' . LB
-                 . '<div dir="ltr" class="warningsmall">';
-        $autotags = array_keys(PLG_collectTags());
-        $allowed .= '[' . implode(':], [', $autotags) . ':]';
-        $allowed .= '</div>';
-        $sp_template->set_var('lang_allowed_html', $allowed);
-    }
+
+    $allowed = COM_allowedHTML('staticpages.edit', false, $_SP_CONF['filter_html']);
+    $sp_template->set_var('lang_allowedhtml', $allowed);
+    $sp_template->set_var('lang_allowed_html', $allowed);
     $sp_template->set_var('lang_hits', $LANG_STATIC['hits']);
     if (empty($A['sp_hits'])) {
         $sp_template->set_var('sp_hits', '0');
@@ -464,6 +482,42 @@ function staticpageeditor_form($A, $error = false)
     return $retval;
 }
 
+/**
+* List all template static pages. For use with a dropdown.
+*
+* @retun    string      HTML for the list
+*
+*/
+function templatelist( $selected = '' )
+{
+    global $_TABLES;
+
+    $retval = '';
+
+    $perms = SP_getPerms();
+    if (!empty($perms)) {
+        $perms = ' AND ' . $perms;
+    }
+
+    $sql = "SELECT sp_id, sp_title FROM {$_TABLES['staticpage']} WHERE template_flag = 1 AND (draft_flag = 0)" . $perms . " ORDER BY sp_title";
+    $result = DB_query ($sql);
+    $nrows = DB_numRows ($result);   
+
+    if ($nrows > 0) {
+        for ($i = 0; $i < $nrows; $i++) {
+            $A = DB_fetchArray ($result);      
+
+            $retval .= '<option value="' . $A['sp_id'] . '"';
+            if ($A['sp_id'] == $selected) {
+                $retval .= ' selected="selected"';
+            }
+            $retval .= '>' . $A['sp_title'] . '</option>'; 
+        }
+    }
+
+    return $retval;
+}
+
 /**
 * List all static pages that the user has access to
 *
@@ -590,6 +644,11 @@ function staticpageeditor($sp_id, $mode = '', $editor = '')
         $A['commentcode'] = $_SP_CONF['comment_code'];
         $A['sp_where'] = 1; // default new pages to "top of page"
         $A['draft_flag'] = $_SP_CONF['draft_flag'];
+        $A['template_flag'] = ''; // Defaults to not a template
+        $A['template_id'] = ''; // Defaults to None
+        if ($_USER['advanced_editor'] == 1) {
+            $A['postmode'] = 'adveditor';
+        }
     } elseif (!empty($sp_id) && $mode == 'clone') {
         $result = DB_query("SELECT *,UNIX_TIMESTAMP(modified) AS unixdate FROM {$_TABLES['staticpage']} WHERE sp_id = '$sp_id'" . COM_getPermSQL('AND', 0, 3));
         if (DB_numRows($result) == 1) {
@@ -674,7 +733,7 @@ function submitstaticpage($sp_id, $sp_title,$sp_page_title, $sp_content, $sp_hit
                           $perm_members, $perm_anon, $sp_php, $sp_nf,
                           $sp_old_id, $sp_centerblock, $sp_help, $sp_tid,
                           $sp_where, $sp_inblock, $postmode, $meta_description,
-                          $meta_keywords, $draft_flag)
+                          $meta_keywords, $draft_flag, $template_flag, $template_id)
 {
     $retval = '';
 
@@ -689,7 +748,9 @@ function submitstaticpage($sp_id, $sp_title,$sp_page_title, $sp_content, $sp_hit
                 'sp_label' => $sp_label,
                 'commentcode' => $commentcode,
                 'meta_description' => $meta_description,
-                'meta_keywords' => $meta_keywords,                
+                'meta_keywords' => $meta_keywords,
+                'template_flag' => $template_flag,
+                'template_id' => $template_id,
                 'draft_flag' => $draft_flag,
                 'owner_id' => $owner_id,
                 'group_id' => $group_id,
@@ -784,6 +845,10 @@ if (($mode == $LANG_ADMIN['delete']) && !empty($LANG_ADMIN['delete']) && SEC_che
         if (!isset($_POST['draft_flag'])) {
             $_POST['draft_flag'] = '';
         }
+        if (!isset($_POST['template_flag'])) {
+            $_POST['template_flag'] = '';
+        }
+        
         $display .= submitstaticpage($sp_id, $_POST['sp_title'], $_POST['sp_page_title'],
             $_POST['sp_content'], COM_applyFilter($_POST['sp_hits'], true),
             COM_applyFilter($_POST['sp_format']), $_POST['sp_onmenu'],
@@ -796,7 +861,7 @@ if (($mode == $LANG_ADMIN['delete']) && !empty($LANG_ADMIN['delete']) && SEC_che
             $sp_help, COM_applyFilter($_POST['sp_tid']),
             COM_applyFilter($_POST['sp_where'], true), $_POST['sp_inblock'],
             COM_applyFilter($_POST['postmode']), $_POST['meta_description'],
-            $_POST['meta_keywords'], $_POST['draft_flag']); 
+            $_POST['meta_keywords'], $_POST['draft_flag'], $_POST['template_flag'], $_POST['template_id']); 
     } else {
         $display = COM_refresh($_CONF['site_admin_url'] . '/index.php');
     }
