@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.6                                                               |
 // +---------------------------------------------------------------------------+
 // | submit.php                                                                |
 // |                                                                           |
 // | Let users submit stories and plugin stuff.                                |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -31,8 +31,6 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: submit.php,v 1.123 2008/07/07 18:24:00 dhaun Exp $
 
 require_once 'lib-common.php';
 require_once $_CONF['path_system'] . 'lib-story.php';
@@ -55,9 +53,9 @@ require_once $_CONF['path_system'] . 'lib-story.php';
 * @return   string          HTML for submission form
 *
 */
-function submissionform($type='story', $mode = '', $topic = '')
+function submissionform($type = 'story', $mode = '', $topic = '')
 {
-    global $_CONF, $_TABLES, $_USER, $LANG12, $LANG_LOGIN;
+    global $_CONF, $_TABLES, $LANG12;
 
     $retval = '';
 
@@ -73,22 +71,9 @@ function submissionform($type='story', $mode = '', $topic = '')
             . $LANG12[31]
             . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
     } else {
-        if (empty ($_USER['username']) &&
+        if (COM_isAnonUser() &&
             (($_CONF['loginrequired'] == 1) || ($_CONF['submitloginrequired'] == 1))) {
-            $retval .= COM_startBlock ($LANG_LOGIN[1], '',
-                               COM_getBlockTemplate ('_msg_block', 'header'));
-            $loginreq = new Template($_CONF['path_layout'] . 'submit');
-            $loginreq->set_file('loginreq', 'submitloginrequired.thtml');
-            $loginreq->set_var('xhtml', XHTML);
-            $loginreq->set_var('site_url', $_CONF['site_url']);
-            $loginreq->set_var('site_admin_url', $_CONF['site_admin_url']);
-            $loginreq->set_var('layout_url', $_CONF['layout_url']);
-            $loginreq->set_var('login_message', $LANG_LOGIN[2]);
-            $loginreq->set_var('lang_login', $LANG_LOGIN[3]);
-            $loginreq->set_var('lang_newuser', $LANG_LOGIN[4]);
-            $loginreq->parse('errormsg', 'loginreq');
-            $retval .= $loginreq->finish($loginreq->get_var('errormsg'));
-            $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+            $retval .= SEC_loginRequiredForm();
             return $retval;
         } else {
             if(!function_exists('CUSTOM_MOBILE_is_cellular') || !CUSTOM_MOBILE_is_cellular()) {
@@ -136,11 +121,8 @@ function submitstory($topic = '')
         $story->initSubmission($topic);
     }
 
-    $retval .= COM_startBlock($LANG12[6],'submitstory.html');
-
-    $storyform = new Template($_CONF['path_layout'] . 'submit');
-    if (isset ($_CONF['advanced_editor']) && ($_CONF['advanced_editor'] == 1) &&
-        file_exists ($_CONF['path_layout'] . 'submit/submitstory_advanced.thtml')) {
+    $storyform = COM_newTemplate($_CONF['path_layout'] . 'submit');
+    if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
         $storyform->set_file('storyform','submitstory_advanced.thtml');
         $storyform->set_var ('change_editormode', 'onchange="change_editmode(this);"');
         $storyform->set_var ('lang_expandhelp', $LANG24[67]);
@@ -162,13 +144,9 @@ function submitstory($topic = '')
             $storyform->set_var ('show_htmleditor', 'none');
         }
     }
-    $storyform->set_var ('xhtml', XHTML);
-    $storyform->set_var ('site_url', $_CONF['site_url']);
-    $storyform->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $storyform->set_var ('layout_url', $_CONF['layout_url']);
     $storyform->set_var ('lang_username', $LANG12[27]);
 
-    if (!empty($_USER['username'])) {
+    if (! COM_isAnonUser()) {
         $storyform->set_var('story_username', $_USER['username']);
         $storyform->set_var('author', COM_getDisplayName ());
         $storyform->set_var('status_url', $_CONF['site_url']
@@ -195,7 +173,12 @@ function submitstory($topic = '')
     $storyform->set_var('story_title', $story->EditElements('title'));
     $storyform->set_var('lang_topic', $LANG12[28]);
 
-    $storyform->set_var('story_topic_options', COM_topicList('tid,topic',$story->EditElements('tid')));
+    $tlist = COM_topicList('tid,topic', $story->EditElements('tid'));
+    if (empty($tlist)) {
+        $retval .= COM_showMessage(101);
+        return $retval;
+    }
+    $storyform->set_var('story_topic_options', $tlist);
     $storyform->set_var('lang_story', $LANG12[29]);
     $storyform->set_var('lang_introtext', $LANG12[54]);
     $storyform->set_var('lang_bodytext', $LANG12[55]);
@@ -207,14 +190,17 @@ function submitstory($topic = '')
     $storyform->set_var('story_uid', $story->EditElements('uid'));
     $storyform->set_var('story_sid', $story->EditElements('sid'));
     $storyform->set_var('story_date', $story->EditElements('unixdate'));
+    $storyform->set_var('lang_preview', $LANG12[32]);
 
+    PLG_templateSetVars('story', $storyform);
     if (($_CONF['skip_preview'] == 1) ||
             (isset($_POST['mode']) && ($_POST['mode'] == $LANG12[32]))) {
-        PLG_templateSetVars ('story', $storyform);
-        $storyform->set_var('save_button', '<input name="mode" type="submit" value="' . $LANG12[8] . '"' . XHTML . '>');
+        $storyform->set_var('save_button',
+                            '<input name="mode" type="submit" value="'
+                            . $LANG12[8] . '"' . XHTML . '>');
     }
 
-    $storyform->set_var('lang_preview', $LANG12[32]);
+    $retval .= COM_startBlock($LANG12[6],'submitstory.html');
     $storyform->parse('theform', 'storyform');
     $retval .= $storyform->finish($storyform->get_var('theform'));
     $retval .= COM_endBlock();
@@ -277,7 +263,7 @@ function sendNotification ($table, $story)
 */
 function savestory ($A)
 {
-    global $_CONF, $_TABLES, $_USER;
+    global $_CONF, $_TABLES;
 
     $retval = '';
 
@@ -327,7 +313,7 @@ function savestory ($A)
 */
 function savesubmission($type, $A)
 {
-    global $_CONF, $_TABLES, $_USER, $LANG12;
+    global $_CONF, $_TABLES, $LANG12;
 
     $retval = COM_siteHeader ();
 
@@ -387,10 +373,11 @@ $display = '';
 
 // note that 'type' _may_ come in through $_GET even when the
 // other parameters are in $_POST
-if (isset ($_POST['type'])) {
-    $type = COM_applyFilter ($_POST['type']);
-} else {
-    $type = COM_applyFilter ($_GET['type']);
+$type = '';
+if (isset($_POST['type'])) {
+    $type = COM_applyFilter($_POST['type']);
+} elseif (isset($_GET['type'])) {
+    $type = COM_applyFilter($_GET['type']);
 }
 
 $mode = '';
@@ -399,7 +386,7 @@ if (isset ($_REQUEST['mode'])) {
 }
 
 if (($mode == $LANG12[8]) && !empty ($LANG12[8])) { // submit
-    if (empty ($_USER['username']) &&
+    if (COM_isAnonUser() &&
         (($_CONF['loginrequired'] == 1) || ($_CONF['submitloginrequired'] == 1))) {
         $display = COM_refresh ($_CONF['site_url'] . '/index.php');
     } else {
@@ -411,7 +398,7 @@ if (($mode == $LANG12[8]) && !empty ($LANG12[8])) { // submit
                          . COM_errorLog ($msg, 2)
                          . submitstory ($topic)
                          . COM_siteFooter();
-                echo $display;
+                COM_output($display);
                 exit;
             }
         }
@@ -447,11 +434,12 @@ if (($mode == $LANG12[8]) && !empty ($LANG12[8])) { // submit
             $pagetitle = '';
             break;
     }
-    $display .= COM_siteHeader ('menu', $pagetitle);
+    $noindex = '<meta name="robots" content="noindex"' . XHTML . '>' . LB;
+    $display .= COM_siteHeader ('menu', $pagetitle, $noindex);
     $display .= submissionform($type, $mode, $topic);
     $display .= COM_siteFooter();
 }
 
-echo $display;
+COM_output($display);
 
 ?>
