@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-webservices.php                                                       |
 // |                                                                           |
 // | WS-related functions needed in more than one place.                       |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2007-2008 by the following authors:                         |
+// | Copyright (C) 2007-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Ramnath R Iyer        - rri AT silentyak DOT com                 |
 // |          Dirk Haun             - dirk AT haun-online DOT de               |
@@ -29,13 +29,19 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: lib-webservices.php,v 1.44 2008/09/21 08:37:12 dhaun Exp $
+
+/**
+* Implementation of the Webservices functions for the Atom Publishing Protocol
+* (AtomPub).
+*/
 
 if (strpos(strtolower($_SERVER['PHP_SELF']), 'lib-webservices.php') !== false) {
     die('This file can not be used on its own!');
 }
 
+/**
+* Namespaces
+*/
 define('WS_ATOM_NS', 'http://www.w3.org/2005/Atom');
 define('WS_APP_NS',  'http://www.w3.org/2007/app');
 define('WS_APP_NS2', 'http://purl.org/atom/app#');
@@ -48,15 +54,11 @@ $WS_TEXT = '';
 // Set = true to enable verbose logging (in error.log)
 $WS_VERBOSE = false;
 
-/* Check for PHP5 */
-if (PHP_VERSION < 5) {
-    $_CONF['disable_webservices'] = true;
-}
 
 /**
  * Displays an error message with the appropriate HTTP error-code
  *
- * @param   string  $error_name     the name of the error
+ * @param   string  $error_code     the name of the error
  * @param   string  $error_desc     a short description of the actual error (optional)
  */
 function WS_error($error_code, $error_desc = '')
@@ -109,7 +111,7 @@ function WS_error($error_code, $error_desc = '')
 /**
  * Dissects the URI and obtains parameters
  *
- * @param   array   $args       the array to store any input parameters
+ * @param   array   &$args       the array to store any input parameters
  */
 function WS_dissectURI(&$args)
 {
@@ -454,7 +456,7 @@ function WS_delete()
  * @param   array      &$args       the array to which the content is to be appended
  * @param   object      $atom_doc   current DOMDocument
  * @param   object      $node       the 'content' node
- * @bugs    I guess we could at least support 'text/plain', 'text/html', etc.
+ * @todo    I guess we could at least support 'text/plain', 'text/html', etc.
  */
 function WS_getContent(&$args, $atom_doc, $node)
 {
@@ -645,8 +647,10 @@ function WS_xmlToArgs(&$args)
 /**
  * Converts an array into an XML entry node
  *
- * @param   DOMDocument &$atom_doc  the Atom document to which the entry should be appended
  * @param   array       $arr        the array which is to be converted into XML
+ * @param   array       $extn_elements Geeklog-specific extension elements
+ * @param   object      &$entry_elem   entry to append to
+ * @param   DOMDocument &$atom_doc  the Atom document to which the entry should be appended
  */
 function WS_arrayToEntryXML($arr, $extn_elements, &$entry_elem, &$atom_doc)
 {
@@ -782,7 +786,7 @@ function WS_authenticate()
     $status = -1;
 
     if (isset($_SERVER['PHP_AUTH_USER'])) {
-        $username = $_SERVER['PHP_AUTH_USER'];
+        $username = COM_applyBasicFilter($_SERVER['PHP_AUTH_USER']);
         $password = $_SERVER['PHP_AUTH_PW'];
 
         if ($WS_VERBOSE) {
@@ -815,7 +819,7 @@ function WS_authenticate()
             $key = trim($key);
             $val = trim($val, "\x22\x27");
             if ($key == 'Username') {
-                $username = $val;
+                $username = COM_applyBasicFilter($val);
             } elseif ($key == 'PasswordDigest') {
                 $pwdigest = $val;
             } elseif ($key == 'Created') {
@@ -858,6 +862,7 @@ function WS_authenticate()
 
         list($auth_type, $auth_data) = explode(' ', $_SERVER['REMOTE_USER']);
         list($username, $password) = explode(':', base64_decode($auth_data));
+        $username = COM_applyBasicFilter($username);
 
         if ($WS_VERBOSE) {
             COM_errorLog("WS: Attempting to log in user '$username' (via \$_SERVER['REMOTE_USER'])");
@@ -976,16 +981,17 @@ function WS_writeSync()
     echo $WS_TEXT;
 }
 
-/*
-* Create a new ID, preferrably from a provided 'Slug:' header
-*
-* @param    string  $slug           Content of the 'Slug:' header
-* @param    int     $max_length     max. length of the created ID
-* @return   string                  new ID
-* 
-* For more information on the 'Slug:' header, see RFC 5023, section 9.7
-*
-*/
+/**
+ * Create a new ID, preferrably from a provided 'Slug:' header
+ *
+ * For more information on the 'Slug:' header, see RFC 5023, section 9.7
+ *
+ * @param    string  $slug           Content of the 'Slug:' header
+ * @param    int     $max_length     max. length of the created ID
+ * @return   string                  new ID
+ * @link     http://tools.ietf.org/html/rfc5023#section-9.7
+ * 
+ */
 function WS_makeId($slug = '', $max_length = 40)
 {
     $sid = COM_makeSid();
